summaryrefslogtreecommitdiffstats
path: root/kstyles/highcolor/highcolor.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kstyles/highcolor/highcolor.cpp')
-rw-r--r--kstyles/highcolor/highcolor.cpp120
1 files changed, 60 insertions, 60 deletions
diff --git a/kstyles/highcolor/highcolor.cpp b/kstyles/highcolor/highcolor.cpp
index a3a520f84..cb485f85c 100644
--- a/kstyles/highcolor/highcolor.cpp
+++ b/kstyles/highcolor/highcolor.cpp
@@ -84,7 +84,7 @@ static TQBitmap lightBmp;
static TQBitmap grayBmp;
static TQBitmap dgrayBmp;
static TQBitmap centerBmp;
-static TQBitmap maskBmp;
+static TQBitmap tqmaskBmp;
static TQBitmap xBmp;
static TQIntDict<GradientSet> gDict;
@@ -242,7 +242,7 @@ void HighColorStyle::renderMenuBlendPixmap( KPixmap& pix, const TQColorGroup &cg
}
-// This function draws primitive elements as well as their masks.
+// This function draws primitive elements as well as their tqmasks.
void HighColorStyle::drawPrimitive( PrimitiveElement pe,
TQPainter *p,
const TQRect &r,
@@ -709,16 +709,16 @@ void HighColorStyle::drawPrimitive( PrimitiveElement pe,
}
- // RADIOBUTTON (exclusive indicator) mask
+ // RADIOBUTTON (exclusive indicator) tqmask
// -------------------------------------------------------------------
case PE_ExclusiveIndicatorMask: {
- if (maskBmp.isNull()) {
- maskBmp = TQBitmap(13, 13, radiomask_bits, true);
- maskBmp.setMask(maskBmp);
+ if (tqmaskBmp.isNull()) {
+ tqmaskBmp = TQBitmap(13, 13, radiotqmask_bits, true);
+ tqmaskBmp.setMask(tqmaskBmp);
}
p->setPen(Qt::color1);
- p->drawPixmap(r.x(), r.y(), maskBmp);
+ p->drawPixmap(r.x(), r.y(), tqmaskBmp);
break;
}
@@ -760,7 +760,7 @@ void HighColorStyle::drawPrimitive( PrimitiveElement pe,
case PE_WindowFrame:
case PE_PanelLineEdit: {
bool sunken = flags & Style_Sunken;
- int lw = opt.isDefault() ? pixelMetric(PM_DefaultFrameWidth)
+ int lw = opt.isDefault() ? tqpixelMetric(PM_DefaultFrameWidth)
: opt.lineWidth();
if (lw == 2)
{
@@ -795,7 +795,7 @@ void HighColorStyle::drawPrimitive( PrimitiveElement pe,
case PE_PanelDockWindow: { // Toolbar
int x2 = r.x()+r.width()-1;
int y2 = r.y()+r.height()-1;
- int lw = opt.isDefault() ? pixelMetric(PM_DefaultFrameWidth)
+ int lw = opt.isDefault() ? tqpixelMetric(PM_DefaultFrameWidth)
: opt.lineWidth();
if (lw)
@@ -889,8 +889,8 @@ void HighColorStyle::drawPrimitive( PrimitiveElement pe,
p->save();
if ( flags & Style_Down )
- p->translate( pixelMetric( PM_ButtonShiftHorizontal ),
- pixelMetric( PM_ButtonShiftVertical ) );
+ p->translate( tqpixelMetric( PM_ButtonShiftHorizontal ),
+ tqpixelMetric( PM_ButtonShiftVertical ) );
if ( flags & Style_Enabled ) {
a.translate( r.x() + r.width() / 2, r.y() + r.height() / 2 );
@@ -1092,7 +1092,7 @@ void HighColorStyle::drawKStylePrimitive( KStylePrimitive kpe,
}
-void HighColorStyle::drawControl( ControlElement element,
+void HighColorStyle::tqdrawControl( ControlElement element,
TQPainter *p,
const TQWidget *widget,
const TQRect &r,
@@ -1115,7 +1115,7 @@ void HighColorStyle::drawControl( ControlElement element,
if ( btnDefault || button->autoDefault() ) {
// Compensate for default indicator
- static int di = pixelMetric( PM_ButtonDefaultIndicator );
+ static int di = tqpixelMetric( PM_ButtonDefaultIndicator );
br.addCoords( di, di, -di, -di );
}
@@ -1141,14 +1141,14 @@ void HighColorStyle::drawControl( ControlElement element,
// Shift button contents if pushed.
if ( active ) {
- x += pixelMetric(PM_ButtonShiftHorizontal, widget);
- y += pixelMetric(PM_ButtonShiftVertical, widget);
+ x += tqpixelMetric(PM_ButtonShiftHorizontal, widget);
+ y += tqpixelMetric(PM_ButtonShiftVertical, widget);
flags |= Style_Sunken;
}
// Does the button have a popup menu?
if ( button->isMenuButton() ) {
- int dx = pixelMetric( PM_MenuButtonIndicator, widget );
+ int dx = tqpixelMetric( PM_MenuButtonIndicator, widget );
drawPrimitive( PE_ArrowDown, p, TQRect(x + w - dx - 2, y + 2, dx, h - 4),
cg, flags, opt );
w -= dx;
@@ -1181,7 +1181,7 @@ void HighColorStyle::drawControl( ControlElement element,
// Make the label indicate if the button is a default button or not
if ( active || button->isDefault() ) {
// Draw "fake" bold text - this enables the font metrics to remain
// the same as computed in TQPushButton::sizeHint(), but gives
// a reasonable bold effect.
int i;
@@ -1189,25 +1189,25 @@ void HighColorStyle::drawControl( ControlElement element,
if (button->isEnabled()) // Don't draw double-shadow when disabled
for(i=0; i<2; i++)
drawItem( p, TQRect(x+i+1, y+1, w, h), AlignCenter | ShowPrefix,
- button->colorGroup(), button->isEnabled(), NULL,
+ button->tqcolorGroup(), button->isEnabled(), NULL,
button->text(), -1,
- active ? &button->colorGroup().dark() : &button->colorGroup().mid() );
+ active ? &button->tqcolorGroup().dark() : &button->tqcolorGroup().mid() );
// Normal Text
for(i=0; i<2; i++)
drawItem( p, TQRect(x+i, y, w, h), AlignCenter | ShowPrefix,
- button->colorGroup(), button->isEnabled(), i == 0 ? button->pixmap() : NULL,
+ button->tqcolorGroup(), button->isEnabled(), i == 0 ? button->pixmap() : NULL,
button->text(), -1,
- active ? &button->colorGroup().light() : &button->colorGroup().buttonText() );
+ active ? &button->tqcolorGroup().light() : &button->tqcolorGroup().buttonText() );
} else
- drawItem( p, TQRect(x, y, w, h), AlignCenter | ShowPrefix, button->colorGroup(),
+ drawItem( p, TQRect(x, y, w, h), AlignCenter | ShowPrefix, button->tqcolorGroup(),
button->isEnabled(), button->pixmap(), button->text(), -1,
- active ? &button->colorGroup().light() : &button->colorGroup().buttonText() );
+ active ? &button->tqcolorGroup().light() : &button->tqcolorGroup().buttonText() );
// Draw a focus rect if the button has focus
if ( flags & Style_HasFocus )
drawPrimitive( PE_FocusRect, p,
- TQStyle::visualRect(subRect(SR_PushButtonFocusRect, widget), widget),
+ TQStyle::tqvisualRect(subRect(SR_PushButtonFocusRect, widget), widget),
cg, flags );
break;
}
@@ -1293,7 +1293,7 @@ void HighColorStyle::drawControl( ControlElement element,
bool enabled = mi->isEnabled();
bool checkable = popupmenu->isCheckable();
bool active = flags & Style_Active;
- bool etchtext = styleHint( SH_EtchDisabledText );
+ bool etchtext = tqstyleHint( SH_EtchDisabledText );
bool reverse = TQApplication::reverseLayout();
int x, y, w, h;
r.rect( &x, &y, &w, &h );
@@ -1324,7 +1324,7 @@ void HighColorStyle::drawControl( ControlElement element,
// Do we have an icon?
if ( mi->iconSet() ) {
TQIconSet::Mode mode;
- TQRect cr = visualRect( TQRect(x, y, checkcol, h), r );
+ TQRect cr = tqvisualRect( TQRect(x, y, checkcol, h), r );
// Select the correct icon from the iconset
if ( active )
@@ -1404,7 +1404,7 @@ void HighColorStyle::drawControl( ControlElement element,
// Does the menu item have a text label?
if ( !s.isNull() ) {
- int t = s.find( '\t' );
+ int t = s.tqfind( '\t' );
int m = itemVMargin;
int text_flags = AlignVCenter | ShowPrefix | DontClip | SingleLine;
text_flags |= reverse ? AlignRight : AlignLeft;
@@ -1459,8 +1459,8 @@ void HighColorStyle::drawControl( ControlElement element,
// Does the menu item have a submenu?
if ( mi->popup() ) {
PrimitiveElement arrow = reverse ? PE_ArrowLeft : PE_ArrowRight;
- int dim = pixelMetric(PM_MenuButtonIndicator);
- TQRect vr = visualRect( TQRect( x + w - arrowHMargin - 2*itemFrame - dim,
+ int dim = tqpixelMetric(PM_MenuButtonIndicator);
+ TQRect vr = tqvisualRect( TQRect( x + w - arrowHMargin - 2*itemFrame - dim,
y + h / 2 - dim / 2, dim, dim), r );
// Draw an arrow at the far end of the menu item
@@ -1480,12 +1480,12 @@ void HighColorStyle::drawControl( ControlElement element,
}
default:
- KStyle::drawControl(element, p, widget, r, cg, flags, opt);
+ KStyle::tqdrawControl(element, p, widget, r, cg, flags, opt);
}
}
-void HighColorStyle::drawControlMask( ControlElement element,
+void HighColorStyle::tqdrawControlMask( ControlElement element,
TQPainter *p,
const TQWidget *widget,
const TQRect &r,
@@ -1506,12 +1506,12 @@ void HighColorStyle::drawControlMask( ControlElement element,
}
default:
- KStyle::drawControlMask(element, p, widget, r, opt);
+ KStyle::tqdrawControlMask(element, p, widget, r, opt);
}
}
-void HighColorStyle::drawComplexControl( ComplexControl control,
+void HighColorStyle::tqdrawComplexControl( ComplexControl control,
TQPainter *p,
const TQWidget *widget,
const TQRect &r,
@@ -1562,7 +1562,7 @@ void HighColorStyle::drawComplexControl( ComplexControl control,
p->drawLine(x+1, y+2, x+1, y2-2);
// Get the button bounding box
- TQRect ar = TQStyle::visualRect(
+ TQRect ar = TQStyle::tqvisualRect(
querySubControlMetrics(CC_ComboBox, widget, SC_ComboBoxArrow),
widget );
@@ -1581,7 +1581,7 @@ void HighColorStyle::drawComplexControl( ComplexControl control,
if ( controls & SC_ComboBoxEditField )
{
const TQComboBox * cb = (const TQComboBox *) widget;
- TQRect re = TQStyle::visualRect(
+ TQRect re = TQStyle::tqvisualRect(
querySubControlMetrics( CC_ComboBox, widget,
SC_ComboBoxEditField), widget );
@@ -1605,7 +1605,7 @@ void HighColorStyle::drawComplexControl( ComplexControl control,
p->fillRect( re.x(), re.y(), re.width(), re.height(),
cg.brush( TQColorGroup::Highlight ) );
- TQRect re = TQStyle::visualRect(
+ TQRect re = TQStyle::tqvisualRect(
subRect(SR_ComboBoxFocusRect, cb), widget);
drawPrimitive( PE_FocusRect, p, re, cg,
@@ -1639,11 +1639,11 @@ void HighColorStyle::drawComplexControl( ComplexControl control,
drawPrimitive(PE_ButtonTool, p, button, cg, bflags, opt);
// Check whether to draw a background pixmap
- else if ( toolbutton->parentWidget() &&
- toolbutton->parentWidget()->backgroundPixmap() &&
- !toolbutton->parentWidget()->backgroundPixmap()->isNull() )
+ else if ( toolbutton->tqparentWidget() &&
+ toolbutton->tqparentWidget()->backgroundPixmap() &&
+ !toolbutton->tqparentWidget()->backgroundPixmap()->isNull() )
{
- TQPixmap pixmap = *(toolbutton->parentWidget()->backgroundPixmap());
+ TQPixmap pixmap = *(toolbutton->tqparentWidget()->backgroundPixmap());
p->drawTiledPixmap( r, pixmap, toolbutton->pos() );
}
else if (widget->parent())
@@ -1693,14 +1693,14 @@ void HighColorStyle::drawComplexControl( ComplexControl control,
default:
- KStyle::drawComplexControl(control, p, widget,
+ KStyle::tqdrawComplexControl(control, p, widget,
r, cg, flags, controls, active, opt);
break;
}
}
-void HighColorStyle::drawComplexControlMask( ComplexControl control,
+void HighColorStyle::tqdrawComplexControlMask( ComplexControl control,
TQPainter *p,
const TQWidget *widget,
const TQRect &r,
@@ -1722,7 +1722,7 @@ void HighColorStyle::drawComplexControlMask( ComplexControl control,
}
default:
- KStyle::drawComplexControlMask(control, p, widget, r, opt);
+ KStyle::tqdrawComplexControlMask(control, p, widget, r, opt);
}
}
@@ -1765,11 +1765,11 @@ TQRect HighColorStyle::subRect(SubRect r, const TQWidget *widget) const
int dbw1 = 0, dbw2 = 0;
if (button->isDefault() || button->autoDefault()) {
- dbw1 = pixelMetric(PM_ButtonDefaultIndicator, widget);
+ dbw1 = tqpixelMetric(PM_ButtonDefaultIndicator, widget);
dbw2 = dbw1 * 2;
}
- int dfw1 = pixelMetric(PM_DefaultFrameWidth, widget) * 2,
+ int dfw1 = tqpixelMetric(PM_DefaultFrameWidth, widget) * 2,
dfw2 = dfw1 * 2;
return TQRect(wrect.x() + dfw1 + dbw1 + 1,
@@ -1781,7 +1781,7 @@ TQRect HighColorStyle::subRect(SubRect r, const TQWidget *widget) const
}
-int HighColorStyle::pixelMetric(PixelMetric m, const TQWidget *widget) const
+int HighColorStyle::tqpixelMetric(PixelMetric m, const TQWidget *widget) const
{
switch(m)
{
@@ -1814,7 +1814,7 @@ int HighColorStyle::pixelMetric(PixelMetric m, const TQWidget *widget) const
}
default:
- return KStyle::pixelMetric(m, widget);
+ return KStyle::tqpixelMetric(m, widget);
}
}
@@ -1832,8 +1832,8 @@ TQSize HighColorStyle::sizeFromContents( ContentsType contents,
const TQPushButton* button = (const TQPushButton*) widget;
int w = contentSize.width();
int h = contentSize.height();
- int bm = pixelMetric( PM_ButtonMargin, widget );
- int fw = pixelMetric( PM_DefaultFrameWidth, widget ) * 2;
+ int bm = tqpixelMetric( PM_ButtonMargin, widget );
+ int fw = tqpixelMetric( PM_DefaultFrameWidth, widget ) * 2;
w += bm + fw + 6; // ### Add 6 to make way for bold font.
h += bm + fw;
@@ -1845,7 +1845,7 @@ TQSize HighColorStyle::sizeFromContents( ContentsType contents,
if ( type != HighColor ) {
// Compensate for default indicator
- int di = pixelMetric( PM_ButtonDefaultIndicator );
+ int di = tqpixelMetric( PM_ButtonDefaultIndicator );
w += di * 2;
h += di * 2;
}
@@ -1871,8 +1871,8 @@ TQSize HighColorStyle::sizeFromContents( ContentsType contents,
int w = contentSize.width(), h = contentSize.height();
if ( mi->custom() ) {
- w = mi->custom()->sizeHint().width();
- h = mi->custom()->sizeHint().height();
+ w = mi->custom()->tqsizeHint().width();
+ h = mi->custom()->tqsizeHint().height();
if ( ! mi->custom()->fullSpan() )
h += 2*itemVMargin + 2*itemFrame;
}
@@ -1898,7 +1898,7 @@ TQSize HighColorStyle::sizeFromContents( ContentsType contents,
2 * itemFrame );
}
- if ( ! mi->text().isNull() && mi->text().find('\t') >= 0 )
+ if ( ! mi->text().isNull() && mi->text().tqfind('\t') >= 0 )
w += 12;
else if ( mi->popup() )
w += 2 * arrowHMargin;
@@ -1922,7 +1922,7 @@ TQSize HighColorStyle::sizeFromContents( ContentsType contents,
}
-// Fix Qt's wacky image alignment
+// Fix Qt's wacky image tqalignment
TQPixmap HighColorStyle::stylePixmap(StylePixmap stylepixmap,
const TQWidget* widget,
const TQStyleOption& opt) const
@@ -1954,12 +1954,12 @@ bool HighColorStyle::eventFilter( TQObject *object, TQEvent *event )
if ( (event->type() == TQEvent::Enter) &&
(button->isEnabled()) ) {
hoverWidget = button;
- button->repaint( false );
+ button->tqrepaint( false );
}
else if ( (event->type() == TQEvent::Leave) &&
(object == hoverWidget) ) {
hoverWidget = 0L;
- button->repaint( false );
+ button->tqrepaint( false );
}
} else if ( object->parent() && !qstrcmp( object->name(), kdeToolbarWidget ) )
{
@@ -1988,7 +1988,7 @@ bool HighColorStyle::eventFilter( TQObject *object, TQEvent *event )
if (tb) horiz_grad = tb->orientation() == Qt::Vertical;
TQPainter p( widget );
- renderGradient(&p, r, parent->colorGroup().button(), horiz_grad,
+ renderGradient(&p, r, parent->tqcolorGroup().button(), horiz_grad,
x_offset, y_offset, pr.width(), pr.height());
return false; // Now draw the contents
@@ -2002,11 +2002,11 @@ bool HighColorStyle::eventFilter( TQObject *object, TQEvent *event )
TQWidget *widget = static_cast<TQWidget*>(object);
TQRect wr = widget->rect(), tr = toolbar->rect();
TQPainter p( widget );
- renderGradient(&p, wr, toolbar->colorGroup().button(),
+ renderGradient(&p, wr, toolbar->tqcolorGroup().button(),
toolbar->orientation() == Qt::Vertical,
wr.x(), wr.y(), tr.width() - 2, tr.height() - 2);
- p.setPen( toolbar->colorGroup().dark() );
+ p.setPen( toolbar->tqcolorGroup().dark() );
if ( toolbar->orientation() == Qt::Horizontal )
p.drawLine( wr.width()-1, 0, wr.width()-1, wr.height()-1 );
else
@@ -2034,7 +2034,7 @@ void HighColorStyle::renderGradient( TQPainter* p, const TQRect& r,
// We use these to draw parent-relative pixmaps for toolbar buttons
// and menubar items.
- GradientSet* grSet = gDict.find( clr.rgb() );
+ GradientSet* grSet = gDict.tqfind( clr.rgb() );
if (!grSet) {
grSet = new GradientSet(clr);
@@ -1181,7 +1181,7 @@ void HighColorStyle::drawControl( ControlElement element,
if ( active || button->isDefault() ) {
// Draw "fake" bold text - this enables the font metrics to remain
- // the same as computed in TQPushButton::sizeHint(), but gives
+ // the same as computed in TQPushButton::tqsizeHint(), but gives
// a reasonable bold effect.
int i;